pub trait DriverTestRealmBuilder {
// Required methods
fn driver_test_realm_manifest_setup<'life0, 'life1, 'async_trait>(
&'life0 self,
manifest_url: &'life1 str,
options: Options,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn driver_test_realm_setup<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn driver_test_realm_add_dtr_exposes<'a, 'life0, 'async_trait>(
&'life0 self,
dtr_exposes: &'a [Capability],
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>
where Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait;
fn driver_test_realm_add_dtr_offers<'a, 'life0, 'async_trait>(
&'life0 self,
dtr_offers: &'a [Capability],
from: Ref,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>
where Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn driver_test_realm_manifest_setup<'life0, 'life1, 'async_trait>(
&'life0 self,
manifest_url: &'life1 str,
options: Options,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn driver_test_realm_manifest_setup<'life0, 'life1, 'async_trait>(
&'life0 self,
manifest_url: &'life1 str,
options: Options,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Set up the DriverTestRealm component in the RealmBuilder realm.
This configures proper input/output routing of capabilities.
This takes a manifest_url to use, which is used by tests that need to
specify a custom driver test realm.
Sourcefn driver_test_realm_setup<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn driver_test_realm_setup<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Set up the DriverTestRealm component in the RealmBuilder realm. This configures proper input/output routing of capabilities.
Sourcefn driver_test_realm_add_dtr_exposes<'a, 'life0, 'async_trait>(
&'life0 self,
dtr_exposes: &'a [Capability],
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait,
fn driver_test_realm_add_dtr_exposes<'a, 'life0, 'async_trait>(
&'life0 self,
dtr_exposes: &'a [Capability],
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait,
For use in conjunction with fuchsia.driver.test.RealmArgs/dtr_exposes defined in
sdk/fidl/fuchsia.driver.test/realm.fidl.
Whenever a dtr_exposes is going to be provided to the RealmArgs, the user MUST call this
function with a reference to the same dtr_exposes vector it intends to use. This will
setup the necessary expose declarations inside the driver test realm and add the necessary
realm_builder routes to support it.
Sourcefn driver_test_realm_add_dtr_offers<'a, 'life0, 'async_trait>(
&'life0 self,
dtr_offers: &'a [Capability],
from: Ref,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait,
fn driver_test_realm_add_dtr_offers<'a, 'life0, 'async_trait>(
&'life0 self,
dtr_offers: &'a [Capability],
from: Ref,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'a: 'async_trait,
'life0: 'async_trait,
For use in conjunction with fuchsia.driver.test.RealmArgs/dtr_offers defined in
sdk/fidl/fuchsia.driver.test/realm.fidl.
Whenever a dtr_offers is going to be provided to the RealmArgs, the user MUST call this
function with a reference to the same dtr_offers vector it intends to use. This will
setup the necessary offers declarations inside the driver test realm and add the necessary
realm_builder routes to support it.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".