pub trait DriverTestRealmBuilder2 {
// Required method
fn driver_test_realm_setup<'life0, 'async_trait>(
&'life0 self,
options: Options,
args: RealmArgs,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn driver_test_realm_setup<'life0, 'async_trait>(
&'life0 self,
options: Options,
args: RealmArgs,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn driver_test_realm_setup<'life0, 'async_trait>(
&'life0 self,
options: Options,
args: RealmArgs,
) -> Pin<Box<dyn Future<Output = Result<&Self>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Set up the driver test realm. This version is a collapsed version compared to the previous version which used a two layer realm builder setup.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".