pub trait DriverTestRealmInstance2 {
// Required methods
fn driver_test_realm_connect_to_dev(&self) -> Result<DirectoryProxy>;
fn wait_for_bootup<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn wait_for_node<'life0, 'life1, 'async_trait>(
&'life0 self,
moniker: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<NodeInfo>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Required Methods
Sourcefn driver_test_realm_connect_to_dev(&self) -> Result<DirectoryProxy>
fn driver_test_realm_connect_to_dev(&self) -> Result<DirectoryProxy>
Connect to the /dev/ directory hosted by DriverTestRealm in this Instance.
Sourcefn wait_for_bootup<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn wait_for_bootup<'life0, 'async_trait>(
&'life0 self,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Waits for the driver manager boot up logic to complete. This will ensure all in-progress binds complete and indicates its safe to proceed with the test or tear down the test realm with no errors.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".